@@ -25,6 +25,9 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#if defined WIN32 && !defined CLOCK && !defined BESTA_OS
+#define CLOCK clock
+#endif
 
 /*
 #ifndef WIN32
@@ -65,9 +68,6 @@
 //#endif
 //#define CLOCK() 0
 #endif
-#ifdef BESTA_OS
-#include <time.h>
-#endif
 
 #ifndef NO_NAMESPACE_GIAC
 namespace giac {
@@ -1151,11 +1151,7 @@ namespace giac {
     }
     bool use_heap=(heap_mult>0 && v1v2>=heap_mult);
     if (debug_infolevel>20){
-#ifdef BESTA_OS
-      CERR << "// " << clock() << "using ";
-#else
       CERR << "// " << CLOCK() << "using ";
-#endif
       if (use_heap)
 	CERR << "heap";
       else
